@@ -7,6 +7,19 @@ with 'BioSAILs::Utils::LoadConfigs';
 
 use MooseX::Types::Path::Tiny qw/Path Paths AbsPath AbsFile/;
 
+app_strict 0;
+app_exclude(
+    'HPC::Runner::Command::Utils',
+    'HPC::Runner::Command::Logger',
+    'HPC::Runner::Command::submit_jobs::Utils',
+    'HPC::Runner::Command::submit_jobs::Plugin',
+    'HPC::Runner::Command::submit_jobs::Logger',
+    'HPC::Runner::Command::stats::Logger',
+    'HPC::Runner::Command::execute_job::Utils',
+    'HPC::Runner::Command::execute_job::Logger',
+    'HPC::Runner::Command::execute_job::Base',
+);
+
 option '+config_base' => ( default => '.hpcrunner', );
 
 =head3 project
@@ -22,7 +35,7 @@ option 'project' => (
       . '#HPC jobname=gzip will be submitted as 001_project_gzip',
     required    => 0,
     predicate   => 'has_project',
-    cmd_aliases => ['p'],
+    cmd_aliases => ['pr'],
 );
 
 option 'no_log_json' => (
@@ -41,7 +54,7 @@ has 'submission_uuid' => (
     predicate => 'has_submissions_uuid',
 );
 
-our $VERSION = '3.2.11';
+our $VERSION = '3.2.12';
 
 app_strict 0;
 
@@ -54,7 +67,7 @@ sub BUILD { }
 =begin HTML
 
 <p><img
-src="http://github.com/jerowe/HPC-Runner-Command/blob/master/_docs/images/rabbit.jpeg"
+src="http://github.com/biosails/HPC-Runner-Command/blob/master/_docs/images/rabbit.jpeg"
 width="500" height="250" alt="HPC::Runner::Command" /></p>
 
 =end HTML
@@ -85,7 +98,7 @@ Get help by heading on over to github and raising an issue. L<GitHub |
 https://github.com/biosails/HPC-Runner-Command/issues>.
 
 Please see the complete documentation at L<HPC::Runner::Command GitBooks |
-https://jerowe.gitbooks.io/hpc-runner-command-docs/content/>.
+https://biosails.gitbooks.io/hpc-runner-command-docs/content/>.
 
 =head1 Quick Start - Create a New Project
 
@@ -193,11 +206,11 @@ Within a job type we can declare dependencies on particular tasks.
 Each scheduler has its own set of variables. HPC::Runner::Command has a set of
 generalized variables for declaring types across templates. For more information
 please see L<Job Scheduler
-Comparison|https://jerowe.gitbooks.io/hpc-runner-command-docs/content/job_submission/comparison.html>
+Comparison|https://biosails.gitbooks.io/hpc-runner-command-docs/content/job_submission/comparison.html>
 
 Additionally, for workflows with a large number of tasks, please see
 L<Considerations for Workflows with a Large Number of
-Tasks|https://jerowe.gitbooks.io/hpc-runner-command-docs/content/design_workflow.html#considerations-for-workflows-with-a-large-number-of-tasks>
+Tasks|https://biosails.gitbooks.io/hpc-runner-command-docs/content/design_workflow.html#considerations-for-workflows-with-a-large-number-of-tasks>
 for information on how to group tasks together.
 
 =head3 Workflow file
